<?php
/**
 * NuvioAxis Green back compat functionality
 *
 * Prevents NuvioAxis Green from running on WordPress versions prior to 3.6,
 * since this theme is not meant to be backward compatible and relies on
 * many new functions and markup changes introduced in 3.6.
 *
 * @package WordPress
 * @subpackage NuvioAxis
 * @since NuvioAxis Green 1.0
 */

/**
 * Prevent switching to NuvioAxis Green on old versions of WordPress.
 *
 * Switches to the default theme.
 *
 * @since NuvioAxis Green 1.0
 *
 * @return void
 */
function nuvioaxis_switch_theme() {
	switch_theme( WP_DEFAULT_THEME, WP_DEFAULT_THEME );
	unset( $_GET['activated'] );
	add_action( 'admin_notices', 'nuvioaxis_upgrade_notice' );
}
add_action( 'after_switch_theme', 'nuvioaxis_switch_theme' );

/**
 * Add message for unsuccessful theme switch.
 *
 * Prints an update nag after an unsuccessful attempt to switch to
 * NuvioAxis Green on WordPress versions prior to 3.6.
 *
 * @since NuvioAxis Green 1.0
 *
 * @return void
 */
function nuvioaxis_upgrade_notice() {
	$message = sprintf( __( 'NuvioAxis Green requires at least WordPress version 3.6. You are running version %s. Please upgrade and try again.', 'nuvioaxis' ), $GLOBALS['wp_version'] );
	printf( '<div class="error"><p>%s</p></div>', $message );
}

/**
 * Prevent the Theme Customizer from being loaded on WordPress versions prior to 3.6.
 *
 * @since NuvioAxis Green 1.0
 *
 * @return void
 */
function nuvioaxis_customize() {
	wp_die( sprintf( __( 'NuvioAxis Green requires at least WordPress version 3.6. You are running version %s. Please upgrade and try again.', 'nuvioaxis' ), $GLOBALS['wp_version'] ), '', array(
		'back_link' => true,
	) );
}
add_action( 'load-customize.php', 'nuvioaxis_customize' );

/**
 * Prevent the Theme Preview from being loaded on WordPress versions prior to 3.4.
 *
 * @since NuvioAxis Green 1.0
 *
 * @return void
 */
function nuvioaxis_preview() {
	if ( isset( $_GET['preview'] ) ) {
		wp_die( sprintf( __( 'NuvioAxis Green requires at least WordPress version 3.6. You are running version %s. Please upgrade and try again.', 'nuvioaxis' ), $GLOBALS['wp_version'] ) );
	}
}
add_action( 'template_redirect', 'nuvioaxis_preview' );
